#include <avr/io.h>
#include <avr/interrupt.h>
#include <inttypes.h>
#include <avr/sleep.h>
#include <avr/interrupt.h>

#ifndef F_CPU
#define F_CPU 1600000UL
#endif

#define LOW 0
#define HIGH 1
#define OUTPUT 1
#define INPUT 0
#define BODS 7   //BOD Sleep bit in MCUCR
#define BODSE 2  //BOD Sleep enable bit in MCUCR

uint8_t mcucr1, mcucr2;

void digitalWrite(int P, int ST)
  {
  if(ST == HIGH)
    {
    PORTB |= (1 << P);
    }
  else
    {
    PORTB &= ~(1 << P);
    }
  }


void pinMode(int P, int ST)
  {
  if(ST == OUTPUT)
    {
    DDRB |= (1 << P);
    }
  else
    {
    DDRB &= ~(1 << P);
    }
  }


// Delay Routine
void delay_ms(unsigned int ms)
  {
  unsigned int zaehler;

  while (ms)
    {
    zaehler = F_CPU / 5000;

    while (zaehler)
      {
      asm volatile ("nop");
      zaehler--;
      }
    ms--;
    }
  }


void goToSleep(void) {
    // GIMSK |= _BV(INT0);                    //enable INT0
    // MCUCR &= ~(_BV(ISC01) | _BV(ISC00));   //INT0 on low level
    ACSR |= _BV(ACD);                         //disable the analog comparator
    ADCSRA &= ~_BV(ADEN);                     //disable ADC
    set_sleep_mode(SLEEP_MODE_PWR_DOWN);
    sleep_enable();
    //turn off the brown-out detector.
    //must have an ATtiny45 or ATtiny85 rev C or later for software to be able to disable the BOD.
    //current while sleeping will be <0.5uA if BOD is disabled, <25uA if not.
    cli();
    mcucr1 = MCUCR | _BV(BODS) | _BV(BODSE);  //turn off the brown-out detector
    mcucr2 = mcucr1 & ~_BV(BODSE);
    MCUCR = mcucr1;
    MCUCR = mcucr2;
    sei();                         //ensure interrupts enabled so we can wake up again
    sleep_cpu();                   //go to sleep
    cli();                         //wake up here, disable interrupts
    // GIMSK = 0x00;               //disable INT0
    sleep_disable();
    sei();                         //enable interrupts again (but INT0 is disabled from above)
}
