/* ***************************************************************************
   *  Kindermann                                 WPK Produktentwicklung      *
   *                                             Schuljahr: 2014/15          *
   *                                                                         *
   *                                                                         *
   *                   Blinkschaltung mit dem ATtiny 85                      *
   *                                                                         *
   *                                                                         *
   *                                                                         *
   ***************************************************************************/


// ATMEL ATTINY85:
//
//                  +-\/-+
//         RESET   1|    |8   Vcc
//           PB3   2|    |7   PB2
//           PB4   3|    |6   PB1   LED (A)
//      	 GND   4|    |5   PB0
//                  +----+
//
// ATtiny85 fuse bits:
// Example for 8 MHz internal oscillator divided by 8 which gives 1MHz
// Fuse high byte:
// 0xde = 1 1 0 1 1 1 1 0 --- BODLEVEL0 (Brown out detection)
//        ^ ^ ^ ^ ^ ^ ^------ BODLEVEL1 (Brown out detection)
//        | | | | | +-------- BODLEVEL2 (Brown out detection)
//        | | | | +---------- EESAVE (set to 0 to preserve EEPROM over chip erase)
//        | | | +------------ WDTON (if set to 0, watchdog is always on)
//        | | +-------------- SPIEN (if set to 1, serial programming is disabled)
//        | +---------------- DWEN (if set to 0, debug wire enabled)
//        +------------------ RSTDISBL (if set to 0, RESET pin is disabled)
//
// Brown out detection
// 111 = disabled
// 110 = VCC 1,8V
// 101 = VCC 2,7V
// 100 = VCC 4,3V
//
// Fuse low byte:
// 0x62 = 0 1 1 0 0 0 1 0
//        ^ ^ ^ ^ \--+--/
//        | | | +------- CKSEL 3..0 (8M internal RC)
//        | | +--------- SUT 1..0 (slowly rising power)
//        | +----------- CKOUT (if set to 0, Clock output on PORTB4)
//        +------------- CKDIV8 (if set to 0, divide clock by 8 internally)
//
//CKSEL table
// 0000 = External clock (not crystal oscillator)
// 0001 = 16MHz PLL clock
// 0010 = 8MHz Internal clock


#ifndef F_CPU
#define F_CPU 16000000UL
#endif

#include <avr/io.h>


// Delay Routine
void delay_ms(unsigned int ms)
  {
  unsigned int zaehler;

  while (ms)
    {
    zaehler = F_CPU / 5000;

    while (zaehler)
      {
      asm volatile ("nop");
      zaehler--;
      }
    ms--;
    }
  }


// Hauptprogramm
int main(void)
  {
  DDRB |= (1 << 1);

  while(1)
    {
    PORTB |= (1<<PORTB1);
    delay_ms(1000);
    PORTB &= ~(1<<PORTB1);
    delay_ms(1000);
    }
  }
